.. _api:

API reference
=============

This page contains detailed information regarding the TidyMS2 API. It assumes that you are familiar
with the :ref:`library architecture <overview>`.

.. toctree::
   :maxdepth: 1

   api/core
   api/algorithms
   api/io
   api/lcms
   api/operators
   api/chemistry
   api/simulation